=========
Documents
=========

.. automodule:: yadm.documents


.. autoclass:: MetaDocument(cls, name, bases, cls_dict)


.. autoclass:: BaseDocument(**kwargs)
    :members: __str__

.. autoclass:: Document(**kwargs)
    :members:

.. autoclass:: DocumentItemMixin
    :members:
    :special-members:

.. autoclass:: EmbeddedDocument(**kwargs)
    :members:
